@@ -73,7 +73,7 @@ class Seti():
             r = requests.post(url=url, json=data, headers={
                 "authorization": self.api_key,
                 "sign": sign_data
-            }, timeout=100)
+            }, timeout=10)
             return r.json()
         except Exception as e:
             return {'msg': str(e), 'code': 5}
@@ -196,8 +196,8 @@ class Seti():
         return ResponseCreateTransaction(self.send_request(data_send_money, encode_data, REVERSAL_PAYMENT_URL))
 
     # Recharger
-
-    def create_recharger(self, value: int,  secret: str, custom_methods: List[str]):
+    
+    def create_recharger(self, value: int,  secret: str, custom_methods: List[str], redirect_url: str):
         self.is_error = False
         self.validate_value(value)
         self.validate_payment_method(custom_methods)
@@ -205,7 +205,7 @@ class Seti():
             "value": value,
             "secret": secret,
             "customMethods": custom_methods,
-
+            "redirectUrl": redirect_url
         }
         CREATE_RECHARGER_URL = "create-recharger"
         encode_data = self.sign_data(data_create_recharger)
